( cd usr/lib ; rm -rf libnautilus-adapter.so )
( cd usr/lib ; ln -sf libnautilus-adapter.so.2.0.0 libnautilus-adapter.so )
( cd usr/lib ; rm -rf libnautilus.so )
( cd usr/lib ; ln -sf libnautilus.so.2.0.0 libnautilus.so )
( cd usr/lib ; rm -rf libnautilus-private.so )
( cd usr/lib ; ln -sf libnautilus-private.so.2.0.0 libnautilus-private.so )
( cd usr/lib ; rm -rf libnautilus-adapter.so.2 )
( cd usr/lib ; ln -sf libnautilus-adapter.so.2.0.0 libnautilus-adapter.so.2 )
( cd usr/lib ; rm -rf libnautilus.so.2 )
( cd usr/lib ; ln -sf libnautilus.so.2.0.0 libnautilus.so.2 )
( cd usr/lib ; rm -rf libnautilus-private.so.2 )
( cd usr/lib ; ln -sf libnautilus-private.so.2.0.0 libnautilus-private.so.2 )
